@@ -141,17 +141,19 @@ def dump_databases(databases, log_prefix, location_config, dry_run):
 
             if dump_format == 'directory':
                 dump.create_parent_directory_for_dump(dump_filename)
+                execute_command(
+                    command, shell=True, extra_environment=extra_environment,
+                )
             else:
                 dump.create_named_pipe_for_dump(dump_filename)
-
-            processes.append(
-                execute_command(
-                    command,
-                    shell=True,
-                    extra_environment=extra_environment,
-                    run_to_completion=False,
+                processes.append(
+                    execute_command(
+                        command,
+                        shell=True,
+                        extra_environment=extra_environment,
+                        run_to_completion=False,
+                    )
                 )
-            )
 
     return processes
 
