@@ -107,13 +107,6 @@ def test_parse_arguments_with_list_json_overrides_default():
     assert arguments['list'].json is True
 
 
-def test_parse_arguments_with_dashed_list_json_overrides_default():
-    arguments = module.parse_arguments('--list', '--json')
-
-    assert 'list' in arguments
-    assert arguments['list'].json is True
-
-
 def test_parse_arguments_with_no_actions_defaults_to_all_actions_enabled():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
@@ -127,14 +120,14 @@ def test_parse_arguments_with_no_actions_defaults_to_all_actions_enabled():
 def test_parse_arguments_with_no_actions_passes_argument_to_relevant_actions():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
-    arguments = module.parse_arguments('--stats', '--files')
+    arguments = module.parse_arguments('--stats', '--list')
 
     assert 'prune' in arguments
     assert arguments['prune'].stats
-    assert arguments['prune'].files
+    assert arguments['prune'].list_archives
     assert 'create' in arguments
     assert arguments['create'].stats
-    assert arguments['create'].files
+    assert arguments['create'].list_files
     assert 'check' in arguments
 
 
@@ -191,16 +184,6 @@ def test_parse_arguments_with_prune_action_leaves_other_actions_disabled():
     assert 'check' not in arguments
 
 
-def test_parse_arguments_with_dashed_prune_action_leaves_other_actions_disabled():
-    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
-
-    arguments = module.parse_arguments('--prune')
-
-    assert 'prune' in arguments
-    assert 'create' not in arguments
-    assert 'check' not in arguments
-
-
 def test_parse_arguments_with_multiple_actions_leaves_other_action_disabled():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
@@ -211,16 +194,6 @@ def test_parse_arguments_with_multiple_actions_leaves_other_action_disabled():
     assert 'check' in arguments
 
 
-def test_parse_arguments_with_multiple_dashed_actions_leaves_other_action_disabled():
-    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
-
-    arguments = module.parse_arguments('--create', '--check')
-
-    assert 'prune' not in arguments
-    assert 'create' in arguments
-    assert 'check' in arguments
-
-
 def test_parse_arguments_with_invalid_arguments_exits():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
@@ -248,12 +221,6 @@ def test_parse_arguments_allows_encryption_mode_with_init():
     module.parse_arguments('--config', 'myconfig', 'init', '--encryption', 'repokey')
 
 
-def test_parse_arguments_allows_encryption_mode_with_dashed_init():
-    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
-
-    module.parse_arguments('--config', 'myconfig', '--init', '--encryption', 'repokey')
-
-
 def test_parse_arguments_requires_encryption_mode_with_init():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
@@ -287,15 +254,6 @@ def test_parse_arguments_allows_init_and_create():
     module.parse_arguments('--config', 'myconfig', 'init', '--encryption', 'repokey', 'create')
 
 
-def test_parse_arguments_disallows_init_and_dry_run():
-    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
-
-    with pytest.raises(ValueError):
-        module.parse_arguments(
-            '--config', 'myconfig', 'init', '--encryption', 'repokey', '--dry-run'
-        )
-
-
 def test_parse_arguments_disallows_repository_unless_action_consumes_it():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
@@ -361,24 +319,12 @@ def test_parse_arguments_allows_archive_with_mount():
     )
 
 
-def test_parse_arguments_allows_archive_with_dashed_extract():
-    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
-
-    module.parse_arguments('--config', 'myconfig', '--extract', '--archive', 'test')
-
-
 def test_parse_arguments_allows_archive_with_restore():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
     module.parse_arguments('--config', 'myconfig', 'restore', '--archive', 'test')
 
 
-def test_parse_arguments_allows_archive_with_dashed_restore():
-    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
-
-    module.parse_arguments('--config', 'myconfig', '--restore', '--archive', 'test')
-
-
 def test_parse_arguments_allows_archive_with_list():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
@@ -457,23 +403,23 @@ def test_parse_arguments_with_stats_flag_but_no_create_or_prune_flag_raises_valu
         module.parse_arguments('--stats', 'list')
 
 
-def test_parse_arguments_with_files_and_create_flags_does_not_raise():
+def test_parse_arguments_with_list_and_create_flags_does_not_raise():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
-    module.parse_arguments('--files', 'create', 'list')
+    module.parse_arguments('--list', 'create')
 
 
-def test_parse_arguments_with_files_and_prune_flags_does_not_raise():
+def test_parse_arguments_with_list_and_prune_flags_does_not_raise():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
-    module.parse_arguments('--files', 'prune', 'list')
+    module.parse_arguments('--list', 'prune')
 
 
-def test_parse_arguments_with_files_flag_but_no_create_or_prune_or_restore_flag_raises_value_error():
+def test_parse_arguments_with_list_flag_but_no_relevant_action_raises_value_error():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
     with pytest.raises(SystemExit):
-        module.parse_arguments('--files', 'list')
+        module.parse_arguments('--list', 'rcreate')
 
 
 def test_parse_arguments_allows_json_with_list_or_info():
@@ -483,12 +429,6 @@ def test_parse_arguments_allows_json_with_list_or_info():
     module.parse_arguments('info', '--json')
 
 
-def test_parse_arguments_allows_json_with_dashed_info():
-    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
-
-    module.parse_arguments('--info', '--json')
-
-
 def test_parse_arguments_disallows_json_with_both_list_and_info():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
@@ -496,6 +436,56 @@ def test_parse_arguments_disallows_json_with_both_list_and_info():
         module.parse_arguments('list', 'info', '--json')
 
 
+def test_parse_arguments_disallows_json_with_both_list_and_rinfo():
+    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
+
+    with pytest.raises(ValueError):
+        module.parse_arguments('list', 'rinfo', '--json')
+
+
+def test_parse_arguments_disallows_json_with_both_rinfo_and_info():
+    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
+
+    with pytest.raises(ValueError):
+        module.parse_arguments('rinfo', 'info', '--json')
+
+
+def test_parse_arguments_disallows_transfer_with_both_archive_and_match_archives():
+    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
+
+    with pytest.raises(ValueError):
+        module.parse_arguments(
+            'transfer',
+            '--source-repository',
+            'source.borg',
+            '--archive',
+            'foo',
+            '--match-archives',
+            'sh:*bar',
+        )
+
+
+def test_parse_arguments_disallows_info_with_both_archive_and_match_archives():
+    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
+
+    with pytest.raises(ValueError):
+        module.parse_arguments('info', '--archive', 'foo', '--match-archives', 'sh:*bar')
+
+
+def test_parse_arguments_disallows_info_with_both_archive_and_prefix():
+    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
+
+    with pytest.raises(ValueError):
+        module.parse_arguments('info', '--archive', 'foo', '--prefix', 'bar')
+
+
+def test_parse_arguments_disallows_info_with_both_prefix_and_match_archives():
+    flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
+
+    with pytest.raises(ValueError):
+        module.parse_arguments('info', '--prefix', 'foo', '--match-archives', 'sh:*bar')
+
+
 def test_parse_arguments_check_only_extract_does_not_raise_extract_subparser_error():
     flexmock(module.collect).should_receive('get_default_config_paths').and_return(['default'])
 
