@@ -9,6 +9,7 @@ from borgmatic.commands import borgmatic as module
 
 
 def test_run_configuration_runs_actions_for_each_repository():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     expected_results = [flexmock(), flexmock()]
     flexmock(module).should_receive('run_actions').and_return(expected_results[:1]).and_return(
@@ -23,6 +24,7 @@ def test_run_configuration_runs_actions_for_each_repository():
 
 
 def test_run_configuration_with_invalid_borg_version_errors():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_raise(ValueError)
     flexmock(module.command).should_receive('execute_hook').never()
     flexmock(module.dispatch).should_receive('call_hooks').never()
@@ -34,6 +36,7 @@ def test_run_configuration_with_invalid_borg_version_errors():
 
 
 def test_run_configuration_logs_monitor_start_error():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     flexmock(module.dispatch).should_receive('call_hooks').and_raise(OSError).and_return(
         None
@@ -50,6 +53,7 @@ def test_run_configuration_logs_monitor_start_error():
 
 
 def test_run_configuration_bails_for_monitor_start_soft_failure():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     error = subprocess.CalledProcessError(borgmatic.hooks.command.SOFT_FAIL_EXIT_CODE, 'try again')
     flexmock(module.dispatch).should_receive('call_hooks').and_raise(error)
@@ -64,6 +68,7 @@ def test_run_configuration_bails_for_monitor_start_soft_failure():
 
 
 def test_run_configuration_logs_actions_error():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     flexmock(module.command).should_receive('execute_hook')
     flexmock(module.dispatch).should_receive('call_hooks')
@@ -79,6 +84,7 @@ def test_run_configuration_logs_actions_error():
 
 
 def test_run_configuration_bails_for_actions_soft_failure():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     flexmock(module.dispatch).should_receive('call_hooks')
     error = subprocess.CalledProcessError(borgmatic.hooks.command.SOFT_FAIL_EXIT_CODE, 'try again')
@@ -94,6 +100,7 @@ def test_run_configuration_bails_for_actions_soft_failure():
 
 
 def test_run_configuration_logs_monitor_finish_error():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     flexmock(module.dispatch).should_receive('call_hooks').and_return(None).and_return(
         None
@@ -110,6 +117,7 @@ def test_run_configuration_logs_monitor_finish_error():
 
 
 def test_run_configuration_bails_for_monitor_finish_soft_failure():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     error = subprocess.CalledProcessError(borgmatic.hooks.command.SOFT_FAIL_EXIT_CODE, 'try again')
     flexmock(module.dispatch).should_receive('call_hooks').and_return(None).and_return(
@@ -127,6 +135,7 @@ def test_run_configuration_bails_for_monitor_finish_soft_failure():
 
 
 def test_run_configuration_logs_on_error_hook_error():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     flexmock(module.command).should_receive('execute_hook').and_raise(OSError)
     expected_results = [flexmock(), flexmock()]
@@ -143,6 +152,7 @@ def test_run_configuration_logs_on_error_hook_error():
 
 
 def test_run_configuration_bails_for_on_error_hook_soft_failure():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     error = subprocess.CalledProcessError(borgmatic.hooks.command.SOFT_FAIL_EXIT_CODE, 'try again')
     flexmock(module.command).should_receive('execute_hook').and_raise(error)
@@ -159,6 +169,7 @@ def test_run_configuration_bails_for_on_error_hook_soft_failure():
 
 def test_run_configuration_retries_soft_error():
     # Run action first fails, second passes
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     flexmock(module.command).should_receive('execute_hook')
     flexmock(module).should_receive('run_actions').and_raise(OSError).and_return([])
@@ -171,6 +182,7 @@ def test_run_configuration_retries_soft_error():
 
 def test_run_configuration_retries_hard_error():
     # Run action fails twice
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     flexmock(module.command).should_receive('execute_hook')
     flexmock(module).should_receive('run_actions').and_raise(OSError).times(2)
@@ -190,7 +202,8 @@ def test_run_configuration_retries_hard_error():
     assert results == error_logs
 
 
-def test_run_repos_ordered():
+def test_run_configuration_repos_ordered():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     flexmock(module.command).should_receive('execute_hook')
     flexmock(module).should_receive('run_actions').and_raise(OSError).times(2)
@@ -208,6 +221,7 @@ def test_run_repos_ordered():
 
 
 def test_run_configuration_retries_round_robbin():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     flexmock(module.command).should_receive('execute_hook')
     flexmock(module).should_receive('run_actions').and_raise(OSError).times(4)
@@ -238,6 +252,7 @@ def test_run_configuration_retries_round_robbin():
 
 
 def test_run_configuration_retries_one_passes():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     flexmock(module.command).should_receive('execute_hook')
     flexmock(module).should_receive('run_actions').and_raise(OSError).and_raise(OSError).and_return(
@@ -266,6 +281,7 @@ def test_run_configuration_retries_one_passes():
 
 
 def test_run_configuration_retry_wait():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     flexmock(module.command).should_receive('execute_hook')
     flexmock(module).should_receive('run_actions').and_raise(OSError).times(4)
@@ -304,6 +320,7 @@ def test_run_configuration_retry_wait():
 
 
 def test_run_configuration_retries_timeout_multiple_repos():
+    flexmock(module).should_receive('verbosity_to_log_level').and_return(logging.INFO)
     flexmock(module.borg_version).should_receive('local_borg_version').and_return(flexmock())
     flexmock(module.command).should_receive('execute_hook')
     flexmock(module).should_receive('run_actions').and_raise(OSError).and_raise(OSError).and_return(
@@ -340,425 +357,387 @@ def test_run_configuration_retries_timeout_multiple_repos():
     assert results == error_logs
 
 
-def test_run_actions_does_not_raise_for_rcreate_action():
-    flexmock(module.borg_rcreate).should_receive('create_repository')
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'rcreate': flexmock(
-            encryption_mode=flexmock(),
-            source_repository=flexmock(),
-            copy_crypt_key=flexmock(),
-            append_only=flexmock(),
-            storage_quota=flexmock(),
-            make_parent_dirs=flexmock(),
-        ),
-    }
+def test_run_actions_runs_rcreate():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    flexmock(borgmatic.actions.rcreate).should_receive('run_rcreate').once()
 
-    list(
+    tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'rcreate': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
 
 
-def test_run_actions_does_not_raise_for_transfer_action():
-    flexmock(module.borg_transfer).should_receive('transfer_archives')
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'transfer': flexmock(),
-    }
+def test_run_actions_runs_transfer():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    flexmock(borgmatic.actions.transfer).should_receive('run_transfer').once()
 
-    list(
+    tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'transfer': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
 
 
-def test_run_actions_calls_hooks_for_prune_action():
-    flexmock(module.borg_prune).should_receive('prune_archives')
-    flexmock(module.command).should_receive('execute_hook').times(
-        4
-    )  # Before/after extract and before/after actions.
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'prune': flexmock(stats=flexmock(), list_archives=flexmock()),
-    }
+def test_run_actions_runs_prune():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    flexmock(borgmatic.actions.prune).should_receive('run_prune').once()
 
-    list(
+    tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'prune': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
 
 
-def test_run_actions_calls_hooks_for_compact_action():
-    flexmock(module.borg_feature).should_receive('available').and_return(True)
-    flexmock(module.borg_compact).should_receive('compact_segments')
-    flexmock(module.command).should_receive('execute_hook').times(
-        4
-    )  # Before/after extract and before/after actions.
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'compact': flexmock(progress=flexmock(), cleanup_commits=flexmock(), threshold=flexmock()),
-    }
+def test_run_actions_runs_compact():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    flexmock(borgmatic.actions.compact).should_receive('run_compact').once()
 
-    list(
+    tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'compact': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
 
 
-def test_run_actions_executes_and_calls_hooks_for_create_action():
-    flexmock(module.borg_create).should_receive('create_archive')
-    flexmock(module.command).should_receive('execute_hook').times(
-        4
-    )  # Before/after extract and before/after actions.
-    flexmock(module.dispatch).should_receive('call_hooks').and_return({})
-    flexmock(module.dispatch).should_receive('call_hooks_even_if_unconfigured').and_return({})
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'create': flexmock(
-            progress=flexmock(), stats=flexmock(), json=flexmock(), list_files=flexmock()
-        ),
-    }
+def test_run_actions_runs_create():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    expected = flexmock()
+    flexmock(borgmatic.actions.create).should_receive('run_create').and_yield(expected).once()
 
-    list(
+    result = tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'create': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
+    assert result == (expected,)
 
 
-def test_run_actions_calls_hooks_for_check_action():
+def test_run_actions_runs_check_when_repository_enabled_for_checks():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
     flexmock(module.checks).should_receive('repository_enabled_for_checks').and_return(True)
-    flexmock(module.borg_check).should_receive('check_archives')
-    flexmock(module.command).should_receive('execute_hook').times(
-        4
-    )  # Before/after extract and before/after actions.
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'check': flexmock(
-            progress=flexmock(), repair=flexmock(), only=flexmock(), force=flexmock()
-        ),
-    }
+    flexmock(borgmatic.actions.check).should_receive('run_check').once()
 
-    list(
+    tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'check': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
 
 
-def test_run_actions_calls_hooks_for_extract_action():
-    flexmock(module.validate).should_receive('repositories_match').and_return(True)
-    flexmock(module.borg_extract).should_receive('extract_archive')
-    flexmock(module.command).should_receive('execute_hook').times(
-        4
-    )  # Before/after extract and before/after actions.
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'extract': flexmock(
-            paths=flexmock(),
-            progress=flexmock(),
-            destination=flexmock(),
-            strip_components=flexmock(),
-            archive=flexmock(),
-            repository='repo',
-        ),
-    }
+def test_run_actions_skips_check_when_repository_not_enabled_for_checks():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    flexmock(module.checks).should_receive('repository_enabled_for_checks').and_return(False)
+    flexmock(borgmatic.actions.check).should_receive('run_check').never()
 
-    list(
+    tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'check': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
 
 
-def test_run_actions_does_not_raise_for_export_tar_action():
-    flexmock(module.validate).should_receive('repositories_match').and_return(True)
-    flexmock(module.borg_export_tar).should_receive('export_tar_archive')
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'export-tar': flexmock(
-            repository=flexmock(),
-            archive=flexmock(),
-            paths=flexmock(),
-            destination=flexmock(),
-            tar_filter=flexmock(),
-            list_files=flexmock(),
-            strip_components=flexmock(),
-        ),
-    }
+def test_run_actions_runs_extract():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    flexmock(borgmatic.actions.extract).should_receive('run_extract').once()
 
-    list(
+    tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'extract': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
 
 
-def test_run_actions_does_not_raise_for_mount_action():
-    flexmock(module.validate).should_receive('repositories_match').and_return(True)
-    flexmock(module.borg_mount).should_receive('mount_archive')
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'mount': flexmock(
-            repository=flexmock(),
-            archive=flexmock(),
-            mount_point=flexmock(),
-            paths=flexmock(),
-            foreground=flexmock(),
-            options=flexmock(),
-        ),
-    }
+def test_run_actions_runs_export_tar():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    flexmock(borgmatic.actions.export_tar).should_receive('run_export_tar').once()
 
-    list(
+    tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'export-tar': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
 
 
-def test_run_actions_does_not_raise_for_rlist_action():
-    flexmock(module.validate).should_receive('repositories_match').and_return(True)
-    flexmock(module.borg_rlist).should_receive('list_repository')
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'rlist': flexmock(repository=flexmock(), json=flexmock()),
-    }
+def test_run_actions_runs_mount():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    flexmock(borgmatic.actions.mount).should_receive('run_mount').once()
 
-    list(
+    tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'mount': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
 
 
-def test_run_actions_does_not_raise_for_list_action():
-    flexmock(module.validate).should_receive('repositories_match').and_return(True)
-    flexmock(module.borg_rlist).should_receive('resolve_archive_name').and_return(flexmock())
-    flexmock(module.borg_list).should_receive('list_archive')
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'list': flexmock(repository=flexmock(), archive=flexmock(), json=flexmock()),
-    }
+def test_run_actions_runs_restore():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    flexmock(borgmatic.actions.restore).should_receive('run_restore').once()
 
-    list(
+    tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'restore': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
 
 
-def test_run_actions_does_not_raise_for_rinfo_action():
-    flexmock(module.validate).should_receive('repositories_match').and_return(True)
-    flexmock(module.borg_rinfo).should_receive('display_repository_info')
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'rinfo': flexmock(repository=flexmock(), json=flexmock()),
-    }
+def test_run_actions_runs_rlist():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    expected = flexmock()
+    flexmock(borgmatic.actions.rlist).should_receive('run_rlist').and_yield(expected).once()
 
-    list(
+    result = tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'rlist': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
+            repository_path='repo',
+        )
+    )
+    assert result == (expected,)
+
+
+def test_run_actions_runs_list():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    expected = flexmock()
+    flexmock(borgmatic.actions.list).should_receive('run_list').and_yield(expected).once()
+
+    result = tuple(
+        module.run_actions(
+            arguments={'global': flexmock(dry_run=False), 'list': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
+            hooks={},
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
+            repository_path='repo',
+        )
+    )
+    assert result == (expected,)
+
+
+def test_run_actions_runs_rinfo():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    expected = flexmock()
+    flexmock(borgmatic.actions.rinfo).should_receive('run_rinfo').and_yield(expected).once()
+
+    result = tuple(
+        module.run_actions(
+            arguments={'global': flexmock(dry_run=False), 'rinfo': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
+            hooks={},
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
+            repository_path='repo',
+        )
+    )
+    assert result == (expected,)
+
+
+def test_run_actions_runs_info():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    expected = flexmock()
+    flexmock(borgmatic.actions.info).should_receive('run_info').and_yield(expected).once()
+
+    result = tuple(
+        module.run_actions(
+            arguments={'global': flexmock(dry_run=False), 'info': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
+            hooks={},
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
+            repository_path='repo',
+        )
+    )
+    assert result == (expected,)
+
+
+def test_run_actions_runs_break_lock():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    flexmock(borgmatic.actions.break_lock).should_receive('run_break_lock').once()
+
+    tuple(
+        module.run_actions(
+            arguments={'global': flexmock(dry_run=False), 'break-lock': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
+            hooks={},
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
 
 
-def test_run_actions_does_not_raise_for_info_action():
-    flexmock(module.validate).should_receive('repositories_match').and_return(True)
-    flexmock(module.borg_rlist).should_receive('resolve_archive_name').and_return(flexmock())
-    flexmock(module.borg_info).should_receive('display_archives_info')
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'info': flexmock(repository=flexmock(), archive=flexmock(), json=flexmock()),
-    }
+def test_run_actions_runs_borg():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    flexmock(borgmatic.actions.borg).should_receive('run_borg').once()
 
-    list(
+    tuple(
         module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
+            arguments={'global': flexmock(dry_run=False), 'borg': flexmock()},
+            config_filename=flexmock(),
+            location={'repositories': []},
+            storage=flexmock(),
+            retention=flexmock(),
+            consistency=flexmock(),
             hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
-            repository_path='repo',
-        )
-    )
-
-
-def test_run_actions_does_not_raise_for_break_lock_action():
-    flexmock(module.validate).should_receive('repositories_match').and_return(True)
-    flexmock(module.borg_break_lock).should_receive('break_lock')
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'break-lock': flexmock(repository=flexmock()),
-    }
-
-    list(
-        module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
-            hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
-            repository_path='repo',
-        )
-    )
-
-
-def test_run_actions_does_not_raise_for_borg_action():
-    flexmock(module.validate).should_receive('repositories_match').and_return(True)
-    flexmock(module.borg_rlist).should_receive('resolve_archive_name').and_return(flexmock())
-    flexmock(module.borg_borg).should_receive('run_arbitrary_borg')
-    arguments = {
-        'global': flexmock(monitoring_verbosity=1, dry_run=False),
-        'borg': flexmock(repository=flexmock(), archive=flexmock(), options=flexmock()),
-    }
-
-    list(
-        module.run_actions(
-            arguments=arguments,
-            config_filename='test.yaml',
-            location={'repositories': ['repo']},
-            storage={},
-            retention={},
-            consistency={},
-            hooks={},
-            local_path=None,
-            remote_path=None,
-            local_borg_version=None,
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
             repository_path='repo',
         )
     )
